Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2175)

Unified Diff: chrome/browser/ui/ash/launcher/app_window_launcher_item_controller.h

Issue 2883193002: WIP
Patch Set: git cl try Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/BUILD.gn ('k') | chrome/browser/ui/ash/launcher/app_window_launcher_item_controller.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/ash/launcher/app_window_launcher_item_controller.h
diff --git a/chrome/browser/ui/ash/launcher/app_window_launcher_item_controller.h b/chrome/browser/ui/ash/launcher/app_window_launcher_item_controller.h
index 0c7b1eabf060a9122ef3abb90b693cb2084aed3b..303b239dc3a696029cbb2eaafb29d149347bfa7b 100644
--- a/chrome/browser/ui/ash/launcher/app_window_launcher_item_controller.h
+++ b/chrome/browser/ui/ash/launcher/app_window_launcher_item_controller.h
@@ -65,8 +65,8 @@ class AppWindowLauncherItemController : public ash::ShelfItemDelegate,
protected:
explicit AppWindowLauncherItemController(const ash::ShelfID& shelf_id);
- // Called when app window is removed from controller.
- virtual void OnWindowRemoved(ui::BaseWindow* window) {}
+ // Called when active app window is changed.
+ virtual void OnActiveWindowChanged(ui::BaseWindow* active_window) {}
// Returns the action performed. Should be one of SHELF_ACTION_NONE,
// SHELF_ACTION_WINDOW_ACTIVATED, or SHELF_ACTION_WINDOW_MINIMIZED.
@@ -79,6 +79,9 @@ class AppWindowLauncherItemController : public ash::ShelfItemDelegate,
ash::ShelfAction ActivateOrAdvanceToNextAppWindow(
ui::BaseWindow* window_to_show);
+ // Returns last active window in the controller or top window.
+ ui::BaseWindow* GetLastActiveWindow();
+
private:
WindowList::iterator GetFromNativeWindow(aura::Window* window);
« no previous file with comments | « chrome/browser/ui/BUILD.gn ('k') | chrome/browser/ui/ash/launcher/app_window_launcher_item_controller.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698